=========
Changelog
=========

Version 1.1.0
=============

:Date: July 16, 2021

- Add customizable template strings for the notification title and body

Version 1.0.1
=============

:Date: June 30, 2021

- FIX: Custom icons not working

Version 1.0.0
=============

:Date: June 30, 2021

- The first public release!
- Based on Apprise v0.9.3